summaryrefslogtreecommitdiffstats
path: root/tests/ui/async-await/issues/issue-51719.rs
diff options
context:
space:
mode:
Diffstat (limited to 'tests/ui/async-await/issues/issue-51719.rs')
-rw-r--r--tests/ui/async-await/issues/issue-51719.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/ui/async-await/issues/issue-51719.rs b/tests/ui/async-await/issues/issue-51719.rs
index 09241f982..1cf388cd8 100644
--- a/tests/ui/async-await/issues/issue-51719.rs
+++ b/tests/ui/async-await/issues/issue-51719.rs
@@ -1,10 +1,10 @@
// edition:2018
//
// Tests that the .await syntax can't be used to make a generator
async fn foo() {}
-fn make_generator() {
+fn make_coroutine() {
let _gen = || foo().await;
//~^ ERROR `await` is only allowed inside `async` functions and blocks
}
@@ -1,10 +1,10 @@
// edition:2018
//
-// Tests that the .await syntax can't be used to make a generator
+// Tests that the .await syntax can't be used to make a coroutine
async fn foo() {}